@@ -11,17 +11,30 @@ Arguments:
 
 Options:
 -h, --help                                show this screen
--b <blocksize>, --block-size=<blocksize>  size of block used when reading file's
-                                          content [default: 4096]
+-b <blocksize>, --block-size=<blocksize>  size of block used when reading
+                                          file's content [default: 4096]
 -d <hashalg>, --digest-alg=<hashalg>      secure hash algorithm [default: md5]
--a <action>, --action=<action>            action on duplicate files 
-                                          (print, remove, move) [default: print]
+-a <action>, --action=<action>            action on duplicate files (pprint,
+                                          print, remove, move)
+                                          [default: pprint]
+                                          -remove removes duplicate files
+                                           except first found
+                                          -move moves duplicate files to
+                                           duplicates driectory, except first
+                                           found
+                                          -print prints result directory where
+                                           keys are hash values and values are
+                                           list of duplicate file paths
+                                          -pprint prints sets of duplicate file
+                                           paths each in it's line where sets
+                                           are separated by blank newline
 -m <directory>, --move=<directory>        move duplicate files to directory
-                                          (used with move action) [default: ./dups]
+                                          (used with move action)
+                                          [default: ./dups]
 """
 
 __author__ = 'Darko Poljak <darko.poljak@gmail.com>'
-__version__ = '0.2.0'
+__version__ = '0.3.0'
 __license__ = 'GPLv3'
 
 __all__ = [
@@ -86,7 +99,8 @@ def rm_file_dups(topdirs=['./'], hashalg='md5', block_size=4096):
             os.remove(f)
 
 
-def mv_file_dups(topdirs=['./'], hashalg='md5', block_size=4096, dest_dir='dups'):
+def mv_file_dups(topdirs=['./'], hashalg='md5', block_size=4096,
+                 dest_dir='dups'):
     """Move duplicate files found in specified directory list.
        First file in list is kept in the original directory.
     """
@@ -101,12 +115,18 @@ def mv_file_dups(topdirs=['./'], hashalg='md5', block_size=4096, dest_dir='dups'
                 shutil.move(f, dest_dir)
 
 
-def iter_file_dups(topdirs=['./'], hashalg='md5', block_size=4096):
-    """Yield list of duplicate files when found in specified directory list.
+def iter_file_dups(topdirs=['./'], rethash=False, hashalg='md5',
+                   block_size=4096):
+    """Yield duplicate files when found in specified directory list.
+       If rethash is True then tuple hash value and duplicate paths list is
+       returned, otherwise duplicate paths list is returned.
     """
     dups = file_dups(topdirs, hashalg, block_size)
-    for fpaths in dups.itervalues():
-        yield fpaths
+    for hash_, fpaths in _dict_iter_items(dups):
+        if rethash:
+            yield (hash_, fpaths)
+        else:
+            yield fpaths
 
 
 def main():
@@ -116,7 +136,7 @@ def main():
     from docopt import docopt
 
     args = docopt(__doc__)
- 
+
     topdirs = args['<directory>']
     if not topdirs:
         topdirs = ['./']
@@ -129,9 +149,17 @@ def main():
         print('Invalid block size "%s"' % args['--block-size'])
         sys.exit(1)
 
-    if action == 'print':
+    if action == 'print' or action == 'pprint':
         dups = file_dups(topdirs, args['--digest-alg'], args['--block-size'])
-        print(json.dumps(dict(dups), indent=4))
+        spam = dict(dups)
+        if spam:
+            if action == 'pprint':
+                for h, fpaths in _dict_iter_items(spam):
+                    for path in fpaths:
+                        print(path)
+                    print('')
+            else:
+                print(json.dumps(spam, indent=4))
     elif action == 'move':
         mv_file_dups(topdirs, args['--digest-alg'], args['--block-size'],
                      args['--move'])
@@ -143,4 +171,4 @@ def main():
 
 # if used as script call main function
 if __name__ == '__main__':
-   main()
+    main()
